@@ -529,14 +529,14 @@ GVApi::onLogin1(bool success, const QByteArray &response, QNetworkReply *reply,
         QUrl url(nextAction);
 
         QUrl oldUrl = reply->request().url();
-        QStringList qiVal = oldUrl.allQueryItemValues ("continue");
-        if (qiVal.length () != 0) {
-            url.addQueryItem ("continue", qiVal[qiVal.length () - 1]);
+        QString lastVal = NwHelpers::getLastQueryItemValue (oldUrl, "continue");
+        if (lastVal.length () != 0) {
+            NwHelpers::appendQueryItem (url, "continue", lastVal);
         }
 
-        qiVal = oldUrl.allQueryItemValues ("followup");
-        if (qiVal.length () != 0) {
-            url.addQueryItem ("followup", qiVal[qiVal.length () - 1]);
+        lastVal = NwHelpers::getLastQueryItemValue (oldUrl, "followup");
+        if (lastVal.length () != 0) {
+            NwHelpers::appendQueryItem (url, "followup", lastVal);
         }
 
         success = postLogin (url, token);
@@ -645,7 +645,6 @@ gonext:
 bool
 GVApi::postLogin(QUrl url, AsyncTaskToken *token)
 {
-    QUrl content;
     QNetworkCookie galx;
     bool found = false;
 
@@ -685,14 +684,11 @@ GVApi::postLogin(QUrl url, AsyncTaskToken *token)
 
     keys = allLoginFields.keys();
 
-    foreach (QString key, keys) {
-        if (key != "dsh") {
-            content.addQueryItem(key, allLoginFields[key].toString());
-        }
-    }
+    QByteArray content =
+            NwHelpers::createPostContent (allLoginFields, QStringList("dsh"));
 
     found =
-    doPostForm(url, content.encodedQuery(), token, this,
+    doPostForm(url, content, token, this,
                SLOT(onLogin2(bool,const QByteArray&,QNetworkReply*,void*)));
     Q_ASSERT(found);
 
@@ -977,19 +973,17 @@ GVApi::resumeTFALogin(AsyncTaskToken *token)
 
         QUrl twoFactorUrl = QUrl::fromPercentEncoding(formAction.toLatin1 ());
 
-        QUrl content = twoFactorUrl;
-        content.addQueryItem("smsUserPin"      , smsUserPin);
-        content.addQueryItem("smsVerifyPin"    , "Verify");
-        content.addQueryItem("PersistentCookie", "yes");
-//        content.addQueryItem("GALX"            , galx.value());
+        QVariantMap m;
+        m["smsUserPin"]       = smsUserPin;
+        m["smsVerifyPin"]     = "Verify";
+        m["PersistentCookie"] = "yes";
+        m["GALX"]             = galx.value();
+        NwHelpers::appendQVMap (m, hiddenLoginFields);
 
-        QStringList keys = hiddenLoginFields.keys();
-        foreach (QString key, keys) {
-            content.addQueryItem(key, hiddenLoginFields[key].toString());
-        }
+        QByteArray content = NwHelpers::createPostContent (m);
 
-        rv = doPostForm(twoFactorUrl, content.encodedQuery(), token, this,
-              SLOT(onLogin2(bool,QByteArray,QNetworkReply*,void*)));
+        rv = doPostForm(twoFactorUrl, content, token, this,
+                        SLOT(onLogin2(bool,QByteArray,QNetworkReply*,void*)));
         Q_ASSERT(rv);
     } while (0);
 
@@ -1363,7 +1357,7 @@ GVApi::onGetPhones(bool success, const QByteArray &response, QNetworkReply *,
                 } else if (strPName == "phoneNumber") {
                     regNumber.number = strVal;
                 } else if (strPName == "type") {
-                    regNumber.chType = strVal[0].toAscii ();
+                    regNumber.chType = strVal[0].toLatin1 ();
                 } else if (strPName == "verified") {
                     regNumber.verified = (strVal == "true");
                 } else if (strPName == "smsEnabled") {
@@ -1726,7 +1720,7 @@ GVApi::parseInboxJson(AsyncTaskToken *token, const QString &strJson,
                 }
 
                 fSms.resize (0);
-                fSms.write (QString("<html>" + result + "</html>").toAscii ());
+                fSms.write (QString("<html>" + result + "</html>").toLatin1 ());
                 fSms.seek (0);
 
                 strQuery =
@@ -1982,11 +1976,14 @@ GVApi::callOut(AsyncTaskToken *token)
 
     QString fwdingNum = token->inParams["source"].toString();
     QString dest = token->inParams["destination"].toString();
+
     QUrl url(GV_HTTPS_M "/x");
-    url.addQueryItem("m" , "call");
-    url.addQueryItem("n" , dest);
-    url.addQueryItem("f" , fwdingNum);
-    url.addQueryItem("v" , "11");
+    QVariantMap m;
+    m["m"] = "call";
+    m["n"] = dest;
+    m["f"] = fwdingNum;
+    m["v"] = "11";
+    NwHelpers::appendQueryItems (url, m);
 
     if (emitLog) {
         Q_DEBUG(QString("Call out: dest=%1, using=%2").arg(dest, fwdingNum));
@@ -2120,7 +2117,7 @@ GVApi::callBack(AsyncTaskToken *token)
     Q_DEBUG(QString("Call back request = %1").arg(strContent));
 
     bool rv =
-    doPostForm(url, strContent.toAscii (), token, this,
+    doPostForm(url, strContent.toLatin1 (), token, this,
                SLOT(onCallback(bool,const QByteArray&,QNetworkReply*,void*)));
     Q_ASSERT(rv);
 
@@ -2205,11 +2202,14 @@ GVApi::sendSms(AsyncTaskToken *token)
     }
 
     QUrl url(GV_HTTPS_M "/x");
-    url.addQueryItem("m" , "sms");
-    url.addQueryItem("n" , token->inParams["destination"].toString());
-    url.addQueryItem("f" , "");
-    url.addQueryItem("v" , "11");
-    url.addQueryItem("txt",token->inParams["text"].toString());
+    QVariantMap m;
+    m["m"]   = "sms";
+    m["n"]   = token->inParams["destination"].toString();
+    m["f"]   = "";
+    m["v"]   = "13";
+    m["txt"] = token->inParams["text"].toString();
+    NwHelpers::appendQueryItems (url, m);
+    url = QUrl(NwHelpers::fullyEncodedString (url));
 
     return doSendSms (url, token);
 }//GVApi::sendSms
@@ -2404,7 +2404,7 @@ GVApi::markInboxEntryAsRead(AsyncTaskToken *token)
 
     QUrl url(GV_HTTPS "/b/0/inbox/mark");
     bool rv =
-    doPost(url, strContent.toAscii(), POST_FORM, UA_DESKTOP, token, this,
+    doPost(url, strContent.toLatin1(), POST_FORM, UA_DESKTOP, token, this,
            SLOT(onMarkAsRead(bool,const QByteArray&,QNetworkReply*,void*)));
     Q_ASSERT(rv);
 
@@ -2499,7 +2499,7 @@ GVApi::deleteInboxEntry(AsyncTaskToken *token)
 //    QUrl url(GV_HTTPS "/b/0/inbox/deleteMessages");
     QUrl url(GV_HTTPS "/inbox/deleteMessages");
     bool rv =
-    doPost(url, strContent.toAscii(), POST_FORM, UA_DESKTOP, token, this,
+    doPost(url, strContent.toLatin1(), POST_FORM, UA_DESKTOP, token, this,
            SLOT(onEntryDeleted(bool,const QByteArray&,QNetworkReply*,void*)));
     Q_ASSERT(rv);
 
