@@ -23,6 +23,10 @@ Contact: yuvraaj@gmail.com
 #include "IMainWindow.h"
 #include "Lib.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+   #include <QUrlQuery>
+#endif
+
 //#define LOGS_SERVER "http://localhost:8000"
 #define LOGS_SERVER "https://qgvdial.yuvraaj.net"
 
@@ -88,7 +92,7 @@ LogUploader::sendLogs()
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.4.1619");
+        QDomText appVerText = doc.createTextNode("0.4.1640");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -112,14 +116,22 @@ LogUploader::sendLogs()
             oneLogFile.appendChild(t);
         }
 
-        // Post the logs to my server
         QUrl url(LOGS_SERVER "/tracker/postLogs");
-        url.addQueryItem ("email", win->m_user.toAscii());
-        url.addQueryItem ("version", "0.4.1619");
+        
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+        QUrlQuery urlQ;
+        urlQ.addQueryItem ("email", win->m_user.toLatin1());
+        urlQ.addQueryItem ("version", "0.4.1640");
+        url.setQuery(urlQ);
+#else
+        url.addQueryItem ("email", win->m_user.toLatin1());
+        url.addQueryItem ("version", "0.4.1640");
+#endif
         QNetworkRequest req(url);
         req.setHeader (QNetworkRequest::ContentTypeHeader, POST_TEXT);
 
-        QNetworkReply *reply = m_nwMgr->post (req, doc.toString().toAscii ());
+        // Post the logs to my server
+        QNetworkReply *reply = m_nwMgr->post (req, doc.toString().toLatin1 ());
         if (!reply) {
             delete task;
             break;
@@ -190,9 +202,9 @@ LogUploader::reportLogin()
                            "}")
                     .arg(win->m_user)
                     .arg(lib.getOsDetails ())
-                    .arg("0.4.1619");
+                    .arg("0.4.1640");
 
-    QNetworkReply *reply = m_nwMgr->post (req, json.toAscii ());
+    QNetworkReply *reply = m_nwMgr->post (req, json.toLatin1 ());
 
     NwReqTracker *tracker = new NwReqTracker(reply, *m_nwMgr, task,
                                              NW_REPLY_TIMEOUT, true, this);
