@@ -179,7 +179,8 @@ MainWindow::connectToChangeNotify(QObject *item, const QString &propName,
 
         Q_DEBUG(QString("Connect %1 to %2").arg(signalName).arg(slotName));
 
-        rv = connect(item, signalName.toAscii().constData(), receiver, slotName);
+        rv =
+        connect(item, signalName.toLatin1().constData(), receiver, slotName);
     } while(0);
 
     return (rv);
@@ -243,6 +244,10 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
                 &oContacts, SLOT(getContactInfoAndModel(QString)));
         connect(contactsPage, SIGNAL(searchContact(QString)),
                 &oContacts, SLOT(searchContacts(QString)));
+        connect(contactsPage, SIGNAL(sigRefreshContacts()),
+                &oContacts, SLOT(refreshLatest()));
+        connect(contactsPage, SIGNAL(sigRefreshContactsFull()),
+                &oContacts, SLOT(refreshFull()));
 
         inboxList = getQMLObject ("InboxList");
         if (NULL == inboxList) {
@@ -252,6 +257,10 @@ MainWindow::declStatusChanged(QDeclarativeView::Status status)
                 this, SLOT(onInboxClicked(QString)));
         connect(inboxList, SIGNAL(showInboxSelector()),
                 this, SLOT(onInboxSelBtnClicked()));
+        connect(inboxList, SIGNAL(sigRefreshInbox()),
+                &oInbox, SLOT(refreshLatest()));
+        connect(inboxList, SIGNAL(sigRefreshInboxFull()),
+                &oInbox, SLOT(refreshFull()));
 
         inboxSelector = getQMLObject ("InboxSelector");
         if (NULL == inboxList) {
